@@ -61,11 +61,12 @@ directly from the C<JSAN::Index> class itself.
 
 =cut
 
+use 5.005;
 use strict;
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.11';
+	$VERSION = '0.12';
 }
 
 # Load the components
@@ -115,12 +116,9 @@ sub dependency {
 
 package JSAN::Index::Release::_Dependency;
 
-use base 'Algorithm::Dependency::Ordered';
+use Params::Util '_INSTANCE';
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '0.11';
-}
+use base 'Algorithm::Dependency::Ordered';
 
 sub new {
 	my $class  = ref $_[0] ? ref shift : shift;
@@ -152,10 +150,10 @@ sub schedule {
 		if ( defined $item and ! ref $item and $item =~ /^(?:\w+)(?:\.\w+)*$/ ) {
 			$item = JSAN::Index::Library->retrieve( name => $item );
 		}
-		if ( UNIVERSAL::isa($item, 'JSAN::Index::Library') ) {
+		if ( _INSTANCE($item, 'JSAN::Index::Library') ) {
 			$item = $item->release;
 		}
-		if ( UNIVERSAL::isa($item, 'JSAN::Index::Release') ) {
+		if ( _INSTANCE($item, 'JSAN::Index::Release') ) {
 			$item = $item->source;
 		}
 		push @cleaned, $item;
@@ -171,11 +169,6 @@ package JSAN::Index::Release::_Source;
 use Algorithm::Dependency::Item ();
 use base 'Algorithm::Dependency::Source';
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '0.11';
-}
-
 sub new {
 	my $class  = ref $_[0] ? ref shift : shift;
 	my %params = @_;
@@ -247,7 +240,7 @@ Adam Kennedy E<lt>cpan@ali.asE<gt>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2005,2006 Adam Kennedy. All rights reserved.
+Copyright 2005, 2006 Adam Kennedy. All rights reserved.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
